"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRedisSessionMiddlewares$ = void 0;
/* tslint:disable */
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var express_session_1 = __importDefault(require("express-session"));
var connect_redis_1 = __importDefault(require("connect-redis"));
var http_errors_1 = __importDefault(require("http-errors"));
var uid_safe_1 = __importDefault(require("uid-safe"));
function createRedisSessionMiddlewares$(_a) {
    var SESSION_SECRET = _a.SESSION_SECRET, SESSION_COOKIE_NAME = _a.SESSION_COOKIE_NAME, SESSION_COOKIE_MAX_AGE = _a.SESSION_COOKIE_MAX_AGE, LANGUAGE_CURRENT = _a.LANGUAGE_CURRENT, redisClient = _a.redisClient, logger = _a.logger;
    function checkSession(req, res, next) {
        if (!req.session) {
            return next(http_errors_1.default(503, 'Session unavailable'));
        }
        if (!req.session.LANGUAGE) {
            req.session.LANGUAGE = LANGUAGE_CURRENT;
        }
        next(); // otherwise continue
    }
    return rxjs_1.of(connect_redis_1.default(express_session_1.default)).pipe(operators_1.switchMap(function (RedisStore) {
        return rxjs_1.zip(rxjs_1.of(express_session_1.default({
            secret: SESSION_SECRET,
            name: SESSION_COOKIE_NAME,
            genid: function (req) {
                var timeStamp = new Date().toLocaleTimeString(undefined, {
                    hour: '2-digit',
                    minute: '2-digit',
                    second: '2-digit',
                });
                logger.info(timeStamp + " : new session was created");
                return uid_safe_1.default.sync(24); // <-- the way express-session generates it
            },
            resave: false,
            saveUninitialized: true,
            cookie: {
                httpOnly: true,
                secure: false,
                maxAge: SESSION_COOKIE_MAX_AGE,
            },
            store: new RedisStore({ client: redisClient.redis }),
        })), rxjs_1.of(checkSession));
    }));
}
exports.createRedisSessionMiddlewares$ = createRedisSessionMiddlewares$;
